<?php
/* File:	log_processor.php
 * Summary:  	Process the new connection
 * 
 * Description: Process the new connection and sort them in various files
 * 
 * License:
 * 
 * This file is part of BBclone (The PHP web counter on steroids)
 *
 * $Header: /cvsroot/bbclone/bbclone/log_processor.php,v 1.15 2002/10/19 12:44:22 jdurden Exp $
 * 
 * Copyright (C) 2001-2002, the BBclone Team (see the file AUTHORS 
 * distributed with this library)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or   
 * (at your option) any later version. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

if (!defined("_LOG_PROCESSOR"))
{
  define("_LOG_PROCESSOR",1);
}
else
{
  return;
}


// *****************************************
// *   Loading all the desired libraries   *
// *****************************************
// (please, look at constant.php before refering to a new directory or file)
require("constants.php");
require($BBC_CONFIG_FILE);
require($BBC_LANGUAGE_PATH . $BBC_LANGUAGE . ".php");
require($BBC_LIB_PATH . "io.php");
require($BBC_LIB_PATH . "extension.php");
require($BBC_LIB_PATH . "browser.php");
require($BBC_LIB_PATH . "os.php");
require($BBC_LIB_PATH . "robot.php");

// Loading all the previous data
require($BBC_ACCESS_FILE);

// *****************************************
// *    Variable & Macro initializations   *
// *****************************************

if (empty($BBC_IGNOREIP))
{
  $ignoreip = "";
}
else
{
  $ignoreip = explode(",", ereg_replace(" ","",$BBC_IGNOREIP));
}

// *****************************************
// *               Functions               *
// *****************************************


// Sorting functions used by usort()
function sort_time_sc($row_a, $row_b)
{
  if ($row_a["time"] == $row_b["time"]) return 0;
  return ($row_a["time"] > $row_b["time"] ) ? 1 : -1;
}

function sort_time_desc($row_a, $row_b)
{
  if ($row_a["time"] == $row_b["time"]) return 0;
  return ($row_a["time"] > $row_b["time"] ) ? -1 : 1;
}

// Check if an IP is blacklisted in the config file
function is_ignored_ip($ip)
{
  global $ignoreip;  

  if (empty($ignoreip))
    {
      return false;
    }

  for($k = sizeof($ignoreip) - 1; $k >=0; $k--)
    {
      if (ereg($ignoreip[$k], $ip))
	{
	  return true;
	}
    }

  return false;
}

// Parse all the counter files of var/ and return an array of N rows, 
// with N the number of new connections, sorted in increasing time of connection.
// The counters files are next emptied.
function counter_to_array()
{
  global $BBC_CACHE_PATH, $BBC_COUNTER_PREFIX, $BBC_COUNTER_SUFFIX;
  global $BBC_ACCESS_LAST_FIELDS, $BBC_COUNTER_NB_FIELDS; 
  global $access;

  $base_file = $BBC_CACHE_PATH . $BBC_COUNTER_PREFIX;
  // We parse ten counters files

  for ($i = 0, $nb_new_entry = 0; $i < 10; $i++) 
    {
      $file_name = $base_file . $i. $BBC_COUNTER_SUFFIX;
      if (!$file = file($file_name)) continue;

      for($j = 0, $nb_entry = 0; $j < sizeof($file); $j++)
	{
	  $tmp = ereg_replace("\n","",$file[$j]);
	  $tmp = explode("|",$tmp);

	  // Avoiding ill formed counter file
	  if (empty($tmp[0])) continue;

	  
	  for($k = 0; ($k < $BBC_COUNTER_NB_FIELDS); $k++)
	    {
	      $counter_array[$nb_new_entry][$BBC_ACCESS_LAST_FIELDS[$k]] = $tmp[$k];
	    }

	  $nb_new_entry++;
	}

      // reset the counter files
      $counter_file = fopen($file_name,"w");
      fclose($counter_file);
    }

  // Sorting $counter_array in increasing time: the older first.
  if (!empty($counter_array))
    {
      usort($counter_array, "sort_time_sc");
    }
  else
    {
      $counter_array = array();
    }

  // Returning $counter_array
  return $counter_array;
}


// Determine the robot, the OS, the browser and the extension of a new connection.
// Update the global statistics according to the result of the detection.
function process_new_connection($connect)
{
  global $extension;
  global $extension_strlist;
  global $browser;
  global $os;
  global $robot;
  global $access;

  // Giving a an identification number to the new connection
  $connect["id"] = $access["stat"]["totalcount"] + 1;
  $connect["visits"] = 1;

  // Detecting the extension
  $tmp = explode(".", $connect["dns"]);
  $connect_ext = strtolower($tmp[sizeof($tmp) - 1]);

  if (ereg("[0-9]+",$connect_ext))
    {
      $connect["ext"] = "numeric";
    }
  elseif (!ereg("\|$connect_ext\|",$extension_strlist))
    {
      $connect["ext"] = "unknown";
    }
  else
    {
      $connect["ext"] = $connect_ext;
    }

  // Recording the detected extension in the global statistics
  $access["stat"]["ext"][$connect["ext"]]++;
  
  // Detecting the robot
  reset($robot);
  while( list($robot_name, $robot_elem) = each($robot) )
    {
      reset($robot_elem["rule"]);
      while( list($pattern, $note) = each($robot_elem["rule"]) )
	{
	  if (eregi($pattern, $connect["agent"], $regs))
	    {
	      $connect["robot"] = $robot_name;

	      if (ereg("\\\\[0-9]{1}",$note))
		{
		  $str = ereg_replace("\\\\([0-9]{1})","\$regs[\\1]",$note);
		  eval("\$str = \"$str\";");
		  $connect["robot_note"] = $str;
		}

	      // Recording the detected robot in the global statistics
	      $access["stat"]["robot"][$robot_name]++;

	      break 2;
	    }
	}
    }

  if (empty($connect["robot"]))
    {
      // Detecting the browser
      reset($browser);
      while( list($browser_name, $browser_elem) = each($browser) )
	{
	  reset($browser_elem["rule"]);
	  while( list($pattern, $note) = each($browser_elem["rule"]) )
	    {
	      if (eregi($pattern, $connect["agent"], $regs))
		{
		  $connect["browser"] = $browser_name;

		  if (ereg("\\\\[0-9]{1}",$note))
		    {
		      $str = ereg_replace("\\\\([0-9]{1})","\$regs[\\1]",$note);
		      eval("\$str = \"$str\";");
		      $connect["browser_note"] = $str;
		    }

		  // Recording the detected browser in the global statistics
		  $access["stat"]["browser"][$browser_name]++;

		  break 2;
		}
	    }
	}
      
      // Detecting the os
      reset($os);
      while( list($os_name, $os_elem) = each($os) )
	{
	  reset($os_elem["rule"]);
	  while( list($pattern, $note) = each($os_elem["rule"]) )
	    {
	      if (eregi($pattern, $connect["agent"], $regs))
		{
		  $connect["os"] = $os_name;

		  if (ereg("\\\\[0-9]{1}",$note))
		    {
		      $str = ereg_replace("\\\\([0-9]{1})","\$regs[\\1]",$note);
		      eval("\$str = \"$str\";");
		      $connect["os_note"] = $str;
		    }

		  // Recording the detected os in the global statistics
		  $access["stat"]["os"][$os_name]++;
		  
		  break 2;
		}
	    }
	}
    }

  return $connect;
}

// Update the time stats into $access["time"]
function update_time_stat($new_time)
{
  global $access;

  // Independent variables
  static $nb_seconds_in_day  = 86400;
  static $nb_seconds_in_week = 604800;

  // Variables for the new time
  $new_hour   = date("G", $new_time);
  $new_wday   = date("w", $new_time);
  $new_day    = date("j", $new_time) - 1;
  $new_month  = date("n", $new_time) - 1;

  // Variables for the last time
  $last_time  = $access["time"]["last"];
  $last_hour  = date("G", $last_time);
  $last_wday  = date("w", $last_time);
  $last_day   = date("j", $last_time) - 1;
  $last_month = date("n", $last_time) - 1;
  $last_lgmonth = date("t", $last_time);

  $nb_seconds_in_last_month = $last_lgmonth * $nb_seconds_in_day;
  $nb_seconds_in_last_year = (date("L", $last_time) ? 366 : 365) * $nb_seconds_in_day;

  // Updating the last connection time to the new one 
  // for the next call of update_time_stat
  $access["time"]["last"] = $new_time;


  // * Updating the hourly time stats (in a day) *
  // *********************************************

  // Setting to zero the time-counters present between the last connections
  // and the new one, and incrementing the new time-counter
  
  // Last day, there are 24 hours == 86400 seconds
  if ( ($new_time - $last_time) > $nb_seconds_in_day )
    {
      for ($k = 0; $k < 24; $k++)
	{
	  $access["time"]["hour"][$k] = 0;
	}
    }
  else
    {
      $elapsed = $new_hour - $last_hour;
      $elapsed = ($elapsed < 0) ? $elapsed + 24 : $elapsed;
      for ($k = 1; $k <= $elapsed; $k++)
	{
	  $access["time"]["hour"][($last_hour + $k) % 24] = 0;
	}    
    }
  
  $access["time"]["hour"][$new_hour]++;
  

  // * Updating the daily time stats (in a week) *
  // *********************************************
  
  // Last week, there are 7 days == 604800 seconds
  if ( ($new_time - $last_time) > $nb_seconds_in_week )
    {
      for ($k = 0; $k < 7; $k++)
	{
	  $access["time"]["wday"][$k] = 0;
	}
    }
  else
    {
      $elapsed = $new_wday - $last_wday;
      $elapsed = ($elapsed < 0) ? $elapsed + 7 : $elapsed;
      for ($k = 1; $k <= $elapsed; $k++)
	{
	  $access["time"]["wday"][($last_wday + $k) % 7] = 0;
	}    
    }
  
  $access["time"]["wday"][$new_wday]++;
  

  // * Updating the daily time stats (in a month) *
  // **********************************************

  // Last month, there are 28, 29, 30 or 31 days
  // Note: 
  //   we have to reset 31 days even if we are a month with less days
  if ( ($new_time - $last_time) > $nb_seconds_in_last_month )
    {
      for ($k = 0; $k < 31; $k++){
	$access["time"]["day"][$k] = 0;
      }
    }
  else
    {
      $elapsed = $new_day - $last_day;
      $elapsed = ($elapsed < 0) ? $elapsed + $last_lgmonth : $elapsed;
      
      for ($k = 1; $k <= $elapsed; $k++)
	{
	  $access["time"]["day"][($last_day + $k) % $last_lgmonth] = 0;
	}    
    }
  
  $access["time"]["day"][$new_day]++;
  

  // * Updating the monthly time stats (in a year) *
  // ***********************************************

  // Last year, there are 12 months 
  if (($new_time - $last_time) > $nb_seconds_in_last_year) 
    {
      for ($k = 0; $k < 12; $k++){
	$access["time"]["month"][$k] = 0;
      }
    }
  else
    {
      $elapsed = $new_month - $last_month;
      $elapsed = ($elapsed < 0) ? $elapsed + 12 : $elapsed;
      
      for ($k = 1; $k <= $elapsed; $k++)
	{
	  $access["time"]["month"][($last_month + $k) % 12] = 0;
	}    
    }
  
  $access["time"]["month"][$new_month]++;
}

// Update the referer stat
function update_referer_stat($referer)
{
  global $access;

  ereg("^http://([a-zA-Z0-9\.\_\/\~\-]+)",$referer,$regs);

  $referer_light = trim($regs[1]);
  $referer_light = ereg_replace("\n","",$referer_light); 
  $referer_light = eregi_replace("index\.htm$","",$referer_light);
  $referer_light = eregi_replace("index\.html$","",$referer_light);
  $referer_light = eregi_replace("index\.phtml$","",$referer_light);
  $referer_light = eregi_replace("index\.pl$","",$referer_light);
  $referer_light = eregi_replace("index\.cgi$","",$referer_light);
  $referer_light = eregi_replace("index\.php[0-9]*$","",$referer_light);
  $referer_light = ereg_replace("/$","",$referer_light);

  if (!empty($referer_light))
    {
      $access["referer"][$referer_light]++;
    }
  else
    {
      $access["referer"]["not_specified"]++;
    }
}


// Transfer the raw data from the main counters of var into $access["last"].
// Any new data (more recent than $BBC_MAXTIME) is used in the global stats
function add_new_connections_to_old()
{
  global $BBC_MAXTIME;
  global $BBC_ACCESS_FILE;
  global $access;

  // Resetting the counter of new connections
  $access["stat"]["newvisits"] = 0;
  $access["stat"]["newcount"] = 0;

  // Loading the new connections
  if (!$new_access = counter_to_array())
    {
      // No new connections
      return 0;
    }

  $nb_new_access = sizeof($new_access);
  $nb_last_access = sizeof($access["last"]);
  

  // Checking if we have new connections or not
  for($k = 0; $k < $nb_new_access; $k++)
    {
      $connect = $new_access[$k];

      // *** Updating various basic counters: ***

      // The script viewed
      if (!empty($connect["script_name"]))
	{
	  $access["page"][$connect["script_name"]]["count"]++;
	  $access["page"][$connect["script_name"]]["uri"] = $connect["script"];
	}
      elseif (!empty($connect["script"]))
	{
	  $access["page"][$connect["script"]]["count"]++;
	  $access["page"][$connect["script"]]["uri"] = $connect["script"];
	}

      // The blacklisting
      if (is_ignored_ip($connect["ip"]))
	{
	  $access["stat"]["blacklisted"]++;
	  continue;
	}

      $connect_time = $connect["time"];

      // The time stats
      update_time_stat($connect["time"]);


      // Check if a previous similar connection has been recorded
      $prev_recorded = 0;
      for( $l = $nb_last_access - 1; 
	   ($l >= 0) && (($connect_time - $access["last"][$l]["time"]) < $BBC_MAXTIME);
	   $l-- )
	{
	  if ( ( $connect["ip"] == $access["last"][$l]["ip"] ) &&
	       ( $connect["agent"] == $access["last"][$l]["agent"] ) )
	    {
	      $access["last"][$l]["time"] = $connect_time;
	      $access["last"][$l]["visits"]++;
	      $access["last"][$l]["script"] = $connect["script"];
	      $access["last"][$l]["script_name"] = $connect["script_name"];
	      $access["stat"]["totalvisits"]++;
	      $access["stat"]["newvisits"]++;
	      $prev_recorded = 1;
	      break;
	    }
	}

      // If not recorded, this new connection becomes a new element 
      // of $access["last"] at the end of this latter.
      // The time order is preserved because $access["last"] is sorted by increasing time.
      if (!$prev_recorded)
	{
	  $access["last"][$nb_last_access] = process_new_connection($connect);
	  $access["stat"]["newvisits"]++;
	  $access["stat"]["newcount"]++;
	  $access["stat"]["totalvisits"]++;
	  $access["stat"]["totalcount"]++;
	  $nb_last_access++;

	  // The referer list is update according to this new visit
	  update_referer_stat($connect["referer"]);
	}
    }

  return $nb_new_access;
}

// Removed unnecessary connections from $access["last"], namely those after the $BBC_MAXVISBLE more recent 
// and older than time() - $BBC_MAXTIME.
function update_last_access()
{
  global $access;
  global $BBC_MAXTIME;
  global $BBC_MAXVISIBLE;
  
  $ctime = time();
  $nb_connect = sizeof($access["last"]);
  for($k = $nb_connect - 1 - $BBC_MAXVISIBLE; $k >= 0; $k--)
    {
      if (($ctime - $access["last"][$k]["time"]) > $BBC_MAXTIME)
	{
	  unset($access["last"][$k]);
	}
    }

  usort($access["last"],"sort_time_sc");

}

function save_access()
{
  global $BBC_ACCESS_FILE;
  global $access;

  $file = fopenlock($BBC_ACCESS_FILE, "w+");
  $text  = "<?php\n";
  $text .= "\$access =\n" . array_to_str($access) . ";\n";
  $text .= "?>";
  
  // Recording
  fputs($file, $text);
  flock($file, 3);
  fclose($file);
}

// The MAIN function which runs all the parts of this script
function log_processor()
{
  if ($nb_newaccess = add_new_connections_to_old())
    {
      update_last_access();
      save_access();
    }

  return $nb_newaccess;
}

?>
