<?php
/* File:	show_detailed.php
 * Summary:  	Display the detailed stats of bbclone
 * 
 * Description:
 * 
 * License:
 * 
 * This file is part of BBclone (The PHP web counter on steroids)
 *
 * $Header: /cvsroot/bbclone/bbclone/show_detailed.php,v 1.12 2002/12/26 12:53:48 jdurden Exp $
 * 
 * Copyright (C) 2001-2002, the BBclone Team (see the file AUTHORS 
 * distributed with this library)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or   
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

require("constants.php");
require($BBC_CONFIG_FILE);

require($BBC_LIB_PATH . "selectlang.php");

require($BBC_LOG_PROCESSOR);
require($BBC_LIB_PATH . "os.php");
require($BBC_LIB_PATH . "browser.php");
require($BBC_LIB_PATH . "extension.php");
require($BBC_LIB_PATH . "robot.php");
require($BBC_LIB_PATH . "html.php");
require($BBC_ACCESS_FILE);

// **************
// *  Functions *
// **************

$fields = explode(",",ereg_replace(" ","",$BBC_DETAILED_STAT_FIELDS));
$nb_fields = sizeof($fields);
$fields_title = array("id" => $_["dstat_ID"], "time" => $_["dstat_Time"], 
		      "visits" => $_["dstat_Visits"], "ext" => $_["dstat_Extension"], 
		      "dns" => $_["dstat_DNS"], "referer" => $_["dstat_From"], 
		      "os" => $_["dstat_OS"], "browser" => $_["dstat_Browser"]);

function show_connect_field($connect, $field)
{
  global $BBC_IMAGES_PATH;
  global $extension;
  global $os;
  global $browser;
  global $robot;
  global $_;

  switch ($field)
    {
    case "id":
      return $connect[$field];
      break;

    case "time":
      return ereg_replace(" ","&nbsp;",date("j M, H:i", $connect["time"]));
      break;

    case "visits":
      return $connect[$field];
      break;

    case "ext":
      $ext=$connect["ext"];
      return "<img src=\"". $BBC_IMAGES_PATH . "ext_" . $connect["ext"] . 
	".png\" alt=\"$ext\">&nbsp;" . $extension[$connect["ext"]];
      break;

    case "dns":
      $str = $connect["dns"];
      $lg_str = strlen($str);
      if ($lg_str > 41)
	{
	  $str = substr($str,0,40) . "...";
	}
      return $str;

      break;

    case "referer":

      ereg("^http://([a-zA-Z0-9\.\-]+)",$connect["referer"],$regs);
      $str = $regs[1];

      if (strcmp($str,"unknown"))
	{
	  $lg_str = strlen($str);
	  if ($lg_str > 41)
	    {
	      $str = substr($str,0,40) . "...";
	    }
	  return "<a href=\"".$connect["referer"]."\">$str</a>";
	}
      else
	{
	  $str = $_["misc_unknown"];
	}
      return $str;

      break;

    case "browser":
      if (empty($connect["robot"]))
	{
	  $browser_type = $connect["browser"];
	  $text = "<img src=\"". $BBC_IMAGES_PATH . $browser[$browser_type]["icon"] . 
	    "\" alt=\"$browser_type\">&nbsp;" . ereg_replace(" ","&nbsp;",$browser[$browser_type]["title"]);
	  if (!empty($connect["browser_note"]))
	    {
	      $text .= "&nbsp;" . $connect["browser_note"];
	    }
	  return $text;
	}
      else
	{
	  return show_connect_field($connect,"robot");
	}
      break;

    case "os":
      if (empty($connect["robot"]))
	{
	  $os_type = $connect["os"];
	  $text = "<img src=\"". $BBC_IMAGES_PATH . $os[$os_type]["icon"] . 
	    "\" alt=\"$os_type\">&nbsp;" . ereg_replace(" ","&nbsp;",$os[$os_type]["title"]);
	  if (!empty($connect["os_note"]))
	    {
	      $text .= "&nbsp;" . $connect["os_note"];
	    }
	  return $text;
	}
      else
	{
	  return show_connect_field($connect,"robot");
	}
      break;

    case "robot":
      $robot_type = $connect["robot"];
      $text = "<img src=\"". $BBC_IMAGES_PATH . $robot[$robot_type]["icon"] . 
	"\" alt=\"$robot_type\">&nbsp;" . ereg_replace(" ","&nbsp;",$robot[$robot_type]["title"]);
      if (!empty($connect["robot_note"]))
	{
	  $text .= "&nbsp;" . $connect["robot_note"];
	}
      return $text;
      break;

    default:
      return $connect[$field];
    }
}


// Determine the color of the connection inside the detailed stats table
function bbc_connect_code_color($connect)
{
  global $BBC_MAXTIME;

  if ((time() - $connect["time"]) < $BBC_MAXTIME)
    {
      return "#f6f9f2";
    }
  // else, it is red if it is a robot
  elseif (!empty($connect["robot"]))
    {
      return "#f9e8e8";
    }
  // or blue if something else
  else
    {
      return "#f4f7f9";
    }
}

// **************
// *    MAIN    *
// **************

$start_time = microtime();
$nb_new_access = log_processor();
$process_time = round((microtime() - $start_time)*100)/100;

echo bbc_html_document_begin();
echo bbc_navbar();
echo bbc_titlebar();

echo "<p align=\"$BBC_GENERAL_ALIGN_STYLE\"><i>\n";

if ($nb_new_access)
{
  echo $_["dstat_New_access"] . ": $nb_new_access.\n";
  echo $_["dstat_Elapsed_time"] . ": $process_time " . $_["misc_second_unit"] . ".<br>\n";
}
else
{
  echo $_["dstat_No_new_access"] . ".<br>\n";
}

echo $_["dstat_Visible_accesses"] . ": $BBC_MAXVISIBLE,\n";
echo "<font color=\"green\">" . $_["dstat_green_rows"] . 
     ":</font> " . $_["dstat_last_visit"] . " < $BBC_MAXTIME ". $_["misc_second_unit"]. ",\n";
echo "<font color=\"blue\">" . $_["dstat_blue_rows"]. 
     ":</font> ". $_["dstat_last_visit"] . " > $BBC_MAXTIME " . $_["misc_second_unit"]. ",\n";
echo "<font color=\"red\">" . $_["dstat_red_rows"]. ":</font> ". $_["dstat_robots"]. ".\n";
echo "</i></p>\n";

echo "<div align=\"$BBC_GENERAL_ALIGN_STYLE\">\n";
// ----echo "<table border=\"0\" cellpadding=\"2\" cellspacing=\"2\" width=\"95%\">\n";
echo "<table border=\"0\" cellpadding=\"2\" cellspacing=\"2\" width=\"95%\"><tr>\n";

for($l = 0; $l < $nb_fields; $l++)
{
//  ---echo "<td><b>".$fields_title[$fields[$l]]."</b></td>\n";
  echo "<td><b>".$fields_title[$fields[$l]]."</b></td>\n";
}

$nb_access = sizeof($access["last"]);
$now = time();

for($k = $nb_access - 1; $k >= max(0,$nb_access - $BBC_MAXVISIBLE); $k--)
{
//  echo "<tr bgcolor=\"" . bbc_connect_code_color($access["last"][$k]) . "\" width=\"100%\">\n";
 echo "<tr bgcolor=\"" . bbc_connect_code_color($access["last"][$k]) . "\">\n";

  for($l = 0; $l < $nb_fields; $l++)
    {
      $cell = show_connect_field($access["last"][$k], $fields[$l]);
      echo "<td>" . (empty($cell) ? "&nbsp;" : $cell) . "</td>\n";
    }
  echo "</tr>\n";
}

echo "</table>\n";
echo "</div>\n";

echo bbc_copyright();
echo "<br>\n";
echo bbc_navbar(1);

echo bbc_html_document_end();
?>
